pub enum ValidationErrorKind {
InvalidSigner,
LowValue(HoprBalance),
LowWinProb(WinningProbability),
ChannelClosed(ChannelId),
EpochMismatch(u32),
IndexTooLow(u64),
InsufficientFunds(ChannelId, HoprBalance),
}Expand description
Contains all possible validation errors that can occur during ticket validation.
Variants
InvalidSigner
Ticket signer does not match the sender.
LowValue(HoprBalance)
Ticket amount is lower than the given minimum value.
LowWinProb(WinningProbability)
Ticket winning probability is lower than the given minimum value.
ChannelClosed(ChannelId)
The given channel is closed or pending to close.
EpochMismatch(u32)
Ticket epoch does not match the given channel epoch.
IndexTooLow(u64)
Ticket index is lower than the given channel ticket index.
InsufficientFunds(ChannelId, HoprBalance)
Not enough funds in the given channel to pay for the ticket.